function wktToGeometry(mapView, wkt) {
    var geometry,
        projection = mapView.getProjection(),
        resolutionAtEquator,
        pointResolution,
        resolutionFactor,
        points = [],
        center,
        radius,
        content,
        i,
        lat,  
        lon,
        coordinates;
    if (wkt.lastIndexOf('POINT', 0) === 0) {
        content = wkt.match(/\([^()]+\)/);
        if (content !== null) {
            coordinates = content[0].match(/-?\d+\.?\d*/g);
            if (coordinates !== null) {
                center = ol.proj.transform([Number(coordinates[1]), Number(coordinates[0])], 'EPSG:4326', projection);
                geometry = new ol.geom.Point(center);
            }
        }
    } else if (wkt.lastIndexOf('POLYGON', 0) === 0) {
        content = wkt.match(/\([^()]+\)/);
        if (content !== null) {
            coordinates = content[0].match(/-?\d+\.?\d*/g);
            if (coordinates !== null) {
                for (i = 0; i < coordinates.length; i += 2) {
                    lat = Number(coordinates[i]);
                    lon = Number(coordinates[i + 1]);
                    points.push(ol.proj.transform([lon, lat], 'EPSG:4326', projection));
                }
                geometry = new ol.geom.Polygon([points]);
            }
        }
    } else if (wkt.lastIndexOf('CIRCLE', 0) === 0) {
        content = wkt.match(/\([^()]+\)/);
        if (content !== null) {
            coordinates = content[0].match(/-?\d+\.?\d*/g);
            if (coordinates !== null) {
                center = ol.proj.transform([Number(coordinates[1]), Number(coordinates[0])], 'EPSG:4326', projection);
                resolutionAtEquator = mapView.getResolution();
                pointResolution = ol.proj.getPointResolution(projection, resolutionAtEquator, center);
                resolutionFactor = resolutionAtEquator / pointResolution;
                radius = (Number(coordinates[2]) / ol.proj.METERS_PER_UNIT.m) * resolutionFactor;
                geometry = new ol.geom.Circle(center, radius);
            }
        }
    } else if (wkt.lastIndexOf('LINESTRING', 0) === 0) {
        content = wkt.match(/\([^()]+\)/);
        if (content !== null) {
            coordinates = content[0].match(/-?\d+\.?\d*/g);
            if (coordinates !== null) {
                for (i = 0; i < coordinates.length; i += 2) {
                    lat = Number(coordinates[i]);
                    lon = Number(coordinates[i + 1]);
                    points.push(ol.proj.transform([lon, lat], 'EPSG:4326', projection));
                }
                geometry = new ol.geom.LineString(points);
            }
        }
    }
    return geometry;
}